SWDEV-470698 - fix formatting, add format check workflow (#657)

This commit is contained in:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
committed by GitHub
parent 5840940caa
commit f7338717ae
1574 changed files with 162972 additions and 199346 deletions
@@ -19,24 +19,22 @@
THE SOFTWARE.
*/
#include <hip_test_common.hh>
// Kernel Function
__global__ void run_printf(int *count) {
*count = printf("Hello World");
}
__global__ void run_printf(int* count) { *count = printf("Hello World"); }
/**
* @addtogroup printf printf
* @{
* @ingroup PrintfTest
* `int printf()` -
* Method to print the content on output device.
*/
* @addtogroup printf printf
* @{
* @ingroup PrintfTest
* `int printf()` -
* Method to print the content on output device.
*/
/**
* Test Description
* ------------------------
* - Test case to verify the printf return value(Number of Characters)for -mprintf-kind=hostcall compiler option
* Test source
* - Test case to verify the printf return value(Number of Characters)for -mprintf-kind=hostcall
* compiler option Test source
* ------------------------
* - catch/unit/printf/printfHost.cc
* Test requirements
@@ -60,16 +58,16 @@ TEST_CASE("Unit_Host_Printf") {
std::string str = "Hello World";
int length = str.length();
#if HT_AMD
REQUIRE(length == *count);
#else
REQUIRE(*count == 0);
#endif
#if HT_AMD
REQUIRE(length == *count);
#else
REQUIRE(*count == 0);
#endif
free(count);
HIP_CHECK(hipFree(count_d));
}
/**
* End doxygen group PrintfTest.
* @}
*/
* End doxygen group PrintfTest.
* @}
*/